@@ -1,8 +1,7 @@
 import click
 
 from energinetml.core.http import run_predict_api
-
-from .utils import discover_model, discover_trained_model
+from energinetml.cli.utils import discover_model, discover_trained_model
 
 
 @click.command()
@@ -12,7 +11,9 @@ from .utils import discover_model, discover_trained_model
               help='Host to serve on (default: 127.0.0.1)')
 @click.option('--port', default=8080, type=int,
               help='Port to serve on (default: 8080)')
-def serve(host, port, model, trained_model):
+@click.option('--model-version', 'model_version', default=None, type=str,
+              help='Model version (used for logging)')
+def serve(host, port, model, trained_model, model_version):
     """
     Serve a HTTP web API for model prediction.
     \f
@@ -21,5 +22,12 @@ def serve(host, port, model, trained_model):
     :param int port:
     :param Model model:
     :param TrainedModel trained_model:
+    :param typing.Optional[str] model_version:
     """
-    run_predict_api(model, trained_model, host, port)
+    run_predict_api(
+        model=model,
+        trained_model=trained_model,
+        model_version=model_version,
+        host=host,
+        port=port,
+    )
